==> patch-4.1.6-ONex-OMS-wms-source-PHP5.3.tar.gz: ShopexErp/app/ome/lib/finder/return/product.php <==
<?php
class ome_finder_return_product{
    var $detail_basic = "售后服务详情";

    function __construct($app){
        $this->app = $app;
        if($_GET['app']!='ome'){
            unset($this->column_edit);
        }
    }

    function detail_basic($return_id){
        $render         = app::get('ome')->render();
        $oProduct       = app::get('ome')->model('return_product');
        $oProduct_items = app::get('ome')->model('return_product_items');
        $oProcess_items = app::get('ome')->model('return_process_items');
        $oReship_item   = app::get('ome')->model('reship_items');
        $oOrder         = app::get('ome')->model('orders');
        $oBranch        = app::get('ome')->model('branch');
        $oReship   = app::get('ome')->model('reship');
        $oDly_corp   = app::get('ome')->model('dly_corp');

        if ($_POST['delivery_id']){
            foreach($_POST['item_id'] as $key => $val){
                $item = array();
                $item['item_id'] = $val;
                $branch_id = $_POST['branch_id'.$val];
                $item['branch_id'] = $branch_id;
                $oProduct_items->save($item);
           }
           $return_product['return_id'] = $return_id;
           $return_product['delivery_id'] = $_POST['delivery_id'];
           $oProduct->save($return_product);
        }
        $product_detail = $oProduct->product_detail($return_id);
        $is_archive = kernel::single('archive_order')->is_archive($product_detail['source']);
        if ($is_archive || $product_detail['archive']=='1') {
           
            $archive_ordObj = kernel::single('archive_interface_orders');
            $order_detail = $archive_ordObj->getOrders(array('order_id'=>$product_detail['order_id']),'*');
        }else{
            $order_detail = $oOrder->dump($product_detail['order_id']);
        }
        $reshipinfo = $oReship->dump(array('return_id'=>$return_id),'return_logi_name,return_logi_no');
        if($reshipinfo){
            $corpinfo = $oDly_corp->dump($reshipinfo['return_logi_name'],'name');
            $product_detail['process_data']['shipcompany'] = $product_detail['process_data']['shipcompany']?$product_detail['process_data']['shipcompany']:$corpinfo['name'];
            $product_detail['process_data']['shiplogino'] = $product_detail['process_data']['logino']?$product_detail['process_data']['logino']:$reshipinfo['return_logi_no'];
        }

        $order_id = $product_detail['order_id'];
        if (!$product_detail['delivery_id']){
            $product_items = array();
            if ($product_detail['items'])
               foreach($product_detail['items'] as $k=>$v){
                $refund = $oReship_item->Get_refund_count($order_id,$v['bn']);
                $v['effective']=$refund;
                $v['branch']=$oReship_item->getBranchCodeByBnAndOd($v['bn'],$order_id);
                
                $v['check_num']=$oProduct_items->getList('num', array('bn'=>$v['bn'],'order_id'=>$order_id));
                
                $product_items[] = $v;
            }
            //获取仓库模式
            $branch_mode = app::get('ome')->getConf('ome.branch.mode');
            $render->pagedata['branch_mode'] = $branch_mode;
            $product_detail['items'] = $product_items;
        }

        //增加售后服务详情显示前的扩展
        foreach(kernel::servicelist('ome.aftersale') as $o){
            if(method_exists($o,'pre_detail_display')){
                $o->pre_detail_display($product_detail);
            }
        }
        if (!is_numeric($product_detail['attachment'])){
            $render->pagedata['attachment_type'] = 'remote';
            $attachment = explode("|",$product_detail['attachment']);
            if($attachment[0]!='')$product_detail['attachment'] = $attachment;
        }
        if ($product_detail['source']=='matrix') {
            $plugin_html_show = kernel::single('ome_aftersale_service')->return_product_detail($product_detail);
        
            $render->pagedata['plugin_html_show'] = $plugin_html_show;
            //售后拒绝按钮
            $return_button = kernel::single('ome_aftersale_service')->return_button($return_id,'5');
            $render->pagedata['return_button'] = json_encode($return_button);    
        }
        
        $cnum=$oProcess_items->getList('num,bn,branch_id',array('order_id'=>$order_id));
        if ($cnum){
            foreach($cnum as $k=>$v){
                $pro_num[$v['bn']][$v['branch_id']] = $v['num'];
            }
            foreach($product_detail['check_data'] as $k=>$v){
                $product_detail['check_data'][$k]['num'] = $pro_num[$v['bn']][$v['branch_id']];
            }
        }
        
        $pcount = $oProduct->count(array('order_id'=>$product_detail['order_id']));
        if($pcount > 1){
           $render->pagedata['is_return_order'] = true;
        }else{
           $render->pagedata['is_return_order'] = false;
        }
        $choose_type_flag = 1;
        $shop_id = $product_detail['shop_id'];
        $router = kernel::single('ome_aftersale_request');
        if ($product_detail['source']=='matrix') {

            if ($product_detail['shop_type'] == 'tmall'){
                $return_model = $this->app->model('return_product_tmall');
                $return_tmall = kernel::single('ome_service_aftersale')->get_return_type(array('return_id' => $return_id));
            }

            if (!$router->setShopId($shop_id)->choose_type()) {
                $choose_type_flag = 0;
            }

            if ($return_tmall && $return_tmall['refund_type'] == 'change'){//天猫换货
                $choose_type_flag = 1;
            }
        }
        
        $render->pagedata['choose_type_flag'] = $choose_type_flag;
        $render->pagedata['product'] = $product_detail;
        $render->pagedata['order'] = $order_detail;

        return $render->fetch('admin/return_product/detail/basic.html');
    }

    public $detail_member_info = '会员信息';
    public function detail_member_info($return_id)
    {
        $render = $this->app->render();

        $preturnModel = $this->app->model('return_product');
        $return_detail = $preturnModel->select()->columns('member_id,delivery_id')->where('return_id=?',$return_id)->instance()->fetch_row();
        $render->pagedata['memberInfo'] = $this->app->model('members')->select()->columns('uname,tel,zip,email,mobile')
                                            ->where('member_id=?',$return_detail['member_id'])
                                            ->instance()->fetch_row();

        $oProduct_delivery = $this->app->model('delivery');
        $render->pagedata['delivery']=$oProduct_delivery->dump($return_detail['delivery_id'],'ship_area,ship_name,ship_addr,ship_zip,ship_tel,ship_email,ship_mobile');
        
        return $render->fetch('admin/return_product/detail/member_info.html');
    }

    public $detail_operation_log = '操作日志';
    public function detail_operation_log($return_id)
    {
        $render = $this->app->render();

        $preturnModel = $this->app->model('return_product');
        $return_detail = $preturnModel->select()->columns('return_bn')->where('return_id=?',$return_id)->instance()->fetch_row();

        $opLogModel = $this->app->model('operation_log');
        $logFilter = array('obj_type'=>'return_product@ome','obj_id'=>$return_id,'obj_name'=>$return_detail['return_bn']);

        $render->pagedata['logs'] = $opLogModel->read_log($logFilter,0,20,'log_id');

        return $render->fetch('admin/return_product/detail/operation_log.html');
    }

    var $column_edit = "操作";
    var $column_edit_width = "200";
    function column_edit($row){

        if(!kernel::single('desktop_user')->is_super()){
            $returnLib = kernel::single('ome_return');

            $has_permission = $returnLib->chkground('aftersale_center','','aftersale_return_edit');
            if (!$has_permission) {
                return false;
            }

        }

        if($row['status'] == '1'||$row['status'] == '2'){
           return '<a target="dialog::{width:700,height:400,title:\'编辑售后服务单号:'.$row['return_bn'].'\'}" href="index.php?app=ome&ctl=admin_return&act=edit&p[0]='.$row['return_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">编辑</a>  ';
        }
    }

    var $addon_cols = 'archive,source,order_id,delivery_id,shop_type,return_type';
    var $column_order_id='订单号';
    var $column_order_id_width='100';
    function column_order_id($row)
    {
        $archive = $row[$this->col_prefix . 'archive'];
        $source = $row[$this->col_prefix . 'source'];
        $order_id = $row[$this->col_prefix . 'order_id'];
        if ($archive == '1' || in_array($source,array('archive'))) {
            
            $archive_ordObj = kernel::single('archive_interface_orders');
            $filter = array('order_id'=>$order_id);
            $order = $archive_ordObj->getOrders($filter,'*');
        }else{
            $orderObj = app::get('ome')->model('orders');
            $filter = array('order_id'=>$order_id);
            $order = $orderObj->dump($filter,'order_bn');
        }
        return $order['order_bn'];
    }

    public function row_style($row)
    {

        if ($row[$this->col_prefix.'source'] == 'matrix' && $row[$this->col_prefix.'shop_type']=='tmall' && $row[$this->col_prefix.'return_type'] == 'change'){
            $style.= 'selected';
        }
        return $style;
    }
}
?>

==> patch-4.3.0-ONex-OMS-wms-source-PHP5.6.tar.gz: ShopexErp/app/ome/lib/finder/return/product.php <==
<?php
class ome_finder_return_product{
    var $detail_basic = "售后服务详情";

    function __construct($app){
        $this->app = $app;
        if($_GET['app']!='ome'){
            unset($this->column_edit);
        }
    }

    function detail_basic($return_id){
        $render         = app::get('ome')->render();
        $oProduct       = app::get('ome')->model('return_product');
        $oProduct_items = app::get('ome')->model('return_product_items');
        $oProcess_items = app::get('ome')->model('return_process_items');
        $oReship_item   = app::get('ome')->model('reship_items');
        $oOrder         = app::get('ome')->model('orders');
        $oBranch        = app::get('ome')->model('branch');
        $oReship   = app::get('ome')->model('reship');
        $oDly_corp   = app::get('ome')->model('dly_corp');

        if ($_POST['delivery_id']){
            foreach($_POST['item_id'] as $key => $val){
                $item = array();
                $item['item_id'] = $val;
                $branch_id = $_POST['branch_id'.$val];
                $item['branch_id'] = $branch_id;
                $oProduct_items->save($item);
           }
           $return_product['return_id'] = $return_id;
           $return_product['delivery_id'] = $_POST['delivery_id'];
           $oProduct->save($return_product);
        }
        $product_detail = $oProduct->product_detail($return_id);
        $is_archive = kernel::single('archive_order')->is_archive($product_detail['source']);
        if ($is_archive || $product_detail['archive']=='1') {
           
            $archive_ordObj = kernel::single('archive_interface_orders');
            $order_detail = $archive_ordObj->getOrders(array('order_id'=>$product_detail['order_id']),'*');
        }else{
            $order_detail = $oOrder->dump($product_detail['order_id']);
        }
        $reshipinfo = $oReship->dump(array('return_id'=>$return_id),'return_logi_name,return_logi_no');
        if($reshipinfo){
            $corpinfo = $oDly_corp->dump($reshipinfo['return_logi_name'],'name');
            $product_detail['process_data']['shipcompany'] = $product_detail['process_data']['shipcompany']?$product_detail['process_data']['shipcompany']:$corpinfo['name'];
            $product_detail['process_data']['shiplogino'] = $product_detail['process_data']['logino']?$product_detail['process_data']['logino']:$reshipinfo['return_logi_no'];
        }

        $order_id = $product_detail['order_id'];
        if (!$product_detail['delivery_id']){
            $product_items = array();
            if ($product_detail['items'])
               foreach($product_detail['items'] as $k=>$v){
                $refund = $oReship_item->Get_refund_count($order_id,$v['bn']);
                $v['effective']=$refund;
                $v['branch']=$oReship_item->getBranchCodeByBnAndOd($v['bn'],$order_id);
                
                $v['check_num']=$oProduct_items->getList('num', array('bn'=>$v['bn'],'order_id'=>$order_id));
                
                $product_items[] = $v;
            }
            //获取仓库模式
            $branch_mode = app::get('ome')->getConf('ome.branch.mode');
            $render->pagedata['branch_mode'] = $branch_mode;
            $product_detail['items'] = $product_items;
        }

        //增加售后服务详情显示前的扩展
        foreach(kernel::servicelist('ome.aftersale') as $o){
            if(method_exists($o,'pre_detail_display')){
                $o->pre_detail_display($product_detail);
            }
        }
        if (!is_numeric($product_detail['attachment'])){
            $render->pagedata['attachment_type'] = 'remote';
            $attachment = explode("|",$product_detail['attachment']);
            if($attachment[0]!='')$product_detail['attachment'] = $attachment;
        }
        if ($product_detail['source']=='matrix') {
            $plugin_html_show = kernel::single('ome_aftersale_service')->return_product_detail($product_detail);
        
            $render->pagedata['plugin_html_show'] = $plugin_html_show;
            //售后拒绝按钮
            $return_button = kernel::single('ome_aftersale_service')->return_button($return_id,'5');
            $render->pagedata['return_button'] = json_encode($return_button);    
        }
        
        $cnum=$oProcess_items->getList('num,bn,branch_id',array('order_id'=>$order_id));
        if ($cnum){
            foreach($cnum as $k=>$v){
                $pro_num[$v['bn']][$v['branch_id']] = $v['num'];
            }
            foreach($product_detail['check_data'] as $k=>$v){
                $product_detail['check_data'][$k]['num'] = $pro_num[$v['bn']][$v['branch_id']];
            }
        }
        
        $pcount = $oProduct->count(array('order_id'=>$product_detail['order_id']));
        if($pcount > 1){
           $render->pagedata['is_return_order'] = true;
        }else{
           $render->pagedata['is_return_order'] = false;
        }
        $choose_type_flag = 1;
        $shop_id = $product_detail['shop_id'];
        $router = kernel::single('ome_aftersale_request');
        if ($product_detail['source']=='matrix') {

            if ($product_detail['shop_type'] == 'tmall' || $product_detail['return_type'] == 'jdchange'){
                $return_model = $this->app->model('return_product_tmall');
                $return_tmall = kernel::single('ome_service_aftersale')->get_return_type(array('return_id' => $return_id));
            }

            if (!$router->setShopId($shop_id)->choose_type()) {
                $choose_type_flag = 0;
            }

            if ($return_tmall && $return_tmall['refund_type'] == 'change'){//天猫换货
                $choose_type_flag = 1;
            }
        }
        
        $render->pagedata['choose_type_flag'] = $choose_type_flag;
        $render->pagedata['product'] = $product_detail;
        $render->pagedata['order'] = $order_detail;

        return $render->fetch('admin/return_product/detail/basic.html');
    }

    public $detail_member_info = '会员信息';
    public function detail_member_info($return_id)
    {
        $render = $this->app->render();

        $preturnModel = $this->app->model('return_product');
        $return_detail = $preturnModel->select()->columns('member_id,delivery_id')->where('return_id=?',$return_id)->instance()->fetch_row();
        $render->pagedata['memberInfo'] = $this->app->model('members')->select()->columns('uname,tel,zip,email,mobile')
                                            ->where('member_id=?',$return_detail['member_id'])
                                            ->instance()->fetch_row();

        $oProduct_delivery = $this->app->model('delivery');
        $render->pagedata['delivery']=$oProduct_delivery->dump($return_detail['delivery_id'],'ship_area,ship_name,ship_addr,ship_zip,ship_tel,ship_email,ship_mobile');
        
        return $render->fetch('admin/return_product/detail/member_info.html');
    }

    public $detail_operation_log = '操作日志';
    public function detail_operation_log($return_id)
    {
        $render = $this->app->render();

        $preturnModel = $this->app->model('return_product');
        $return_detail = $preturnModel->select()->columns('return_bn')->where('return_id=?',$return_id)->instance()->fetch_row();

        $opLogModel = $this->app->model('operation_log');
        $logFilter = array('obj_type'=>'return_product@ome','obj_id'=>$return_id,'obj_name'=>$return_detail['return_bn']);

        $render->pagedata['logs'] = $opLogModel->read_log($logFilter,0,20,'log_id');

        return $render->fetch('admin/return_product/detail/operation_log.html');
    }

    var $column_edit = "操作";
    var $column_edit_width = "200";
    function column_edit($row){

        if(!kernel::single('desktop_user')->is_super()){
            $returnLib = kernel::single('ome_return');

            $has_permission = $returnLib->chkground('aftersale_center','','aftersale_return_edit');
            if (!$has_permission) {
                return false;
            }

        }

        if($row['status'] == '1'||$row['status'] == '2'){
           return '<a target="dialog::{width:700,height:400,title:\'编辑售后服务单号:'.$row['return_bn'].'\'}" href="index.php?app=ome&ctl=admin_return&act=edit&p[0]='.$row['return_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">编辑</a>  ';
        }
    }

    var $addon_cols = 'archive,source,order_id,delivery_id,shop_type,return_type,return_id';
    var $column_order_id='订单号';
    var $column_order_id_width='100';
    function column_order_id($row)
    {
        $archive = $row[$this->col_prefix . 'archive'];
        $source = $row[$this->col_prefix . 'source'];
        $order_id = $row[$this->col_prefix . 'order_id'];
        if ($archive == '1' || in_array($source,array('archive'))) {
            
            $archive_ordObj = kernel::single('archive_interface_orders');
            $filter = array('order_id'=>$order_id);
            $order = $archive_ordObj->getOrders($filter,'*');
        }else{
            $orderObj = app::get('ome')->model('orders');
            $filter = array('order_id'=>$order_id);
            $order = $orderObj->dump($filter,'order_bn');
        }
        return $order['order_bn'];
    }

    public function row_style($row)
    {

        if ($row[$this->col_prefix.'source'] == 'matrix' && $row[$this->col_prefix.'shop_type']=='tmall' && $row[$this->col_prefix.'return_type'] == 'change'){
            $style.= 'selected';
        }
        return $style;
    }

    var $column_time_out = '超时时间';
    var $column_time_out_width='120';
    function column_time_out($row){

        if ($row[$this->col_prefix.'source'] == 'matrix' && $row[$this->col_prefix.'shop_type']=='tmall' && $row[$this->col_prefix.'return_type'] == 'change'){
            $tmallObj = app::get('ome')->model('return_product_tmall');
            $tmall_detail = $tmallObj->dump(array('return_id'=>$row[$this->col_prefix . 'return_id'],'refund_type'=>'change'),'current_phase_timeout');
            if ($tmall_detail && $tmall_detail['current_phase_timeout']){
               return "<div style='width:120px;height:20px;background-color:green;color:#FFFFFF;text-align:center;'>".date('Y-m-d H:i:s',$tmall_detail['current_phase_timeout'])."</div>";;
            }

        }else{
            return '-';
        }

    }
}
?>
